package org.jxul.css;

import java.io.*;

/**
 * A class to lex CSS files
 */
public class CssLexer
{   
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }
    
    String filename;
    PushbackReader pbr;
    StringBuffer tokVal = new StringBuffer();
    boolean beginStatements = false;

    // set up the input stream
    public CssLexer(String filename) throws IOException
    {
        this.filename = filename;
        FileReader fr = new FileReader(filename);
        pbr = new PushbackReader(fr);
    }

    // nextToken()
    public CssToken nextToken() throws IOException
    {
        int c = '\0';
    
        tokVal.setLength(0); // reset
        boolean tokStart=false;
        
        while ( (c = (pbr.read())) != -1)
        {            
            switch (c)
            {
                case '{':
                        beginStatements = true;
                        if (tokStart)
                        {
                            // selector
                            if (debug) System.out.println("Returning SELECTOR");
                            return new CssToken(CssToken.TOK_SELECTOR, tokVal.toString());
                        }
                    break;
                case '}':
                        beginStatements = false;
                        if (tokStart)
                        {
                            if (debug) System.out.println("Returning STATEMENT");
                            return new CssToken(CssToken.TOK_STATEMENT, tokVal.toString());                            
                        }                                                
                    break;
                case ';':
                        if (tokStart)
                        {
                            if (debug) System.out.println("Returning STATEMENT");
                            return new CssToken(CssToken.TOK_STATEMENT, tokVal.toString());                            
                        }                                                                    
                    break;
                default:
                    if (Character.isWhitespace((char)c))
                    {
                        if (tokStart && !beginStatements)
                        {
                            // selector
                            if (debug) System.out.println("Returning SELECTOR");
                            return new CssToken(CssToken.TOK_SELECTOR, tokVal.toString());
                        }
                        else if (tokStart && beginStatements)
                        {
                            // whitespace is significant                            
                            tokVal.append((char)c);
                        }                        
                    }
                    else
                    {
                        if (!tokStart)
                            tokStart = true;
                        tokVal.append((char)c);    
                    }
            } // end of switch(c)
        }
        return null;
    }

    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}
