/* Style.java */
package org.jxul.css;

import java.io.*;
import java.awt.*;
import javax.swing.*;
import java.util.*;

import org.w3c.dom.*;

import org.jxul.util.*;
import org.jxul.framework.*;

/**
 * A CSS Style
 */
public class Style
{
    public static final String NONAME="NONAME";
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }
    
    String selector;
    Hashtable styleProperties = new Hashtable();    
    String [] statements;
    private Vector statementVector = new Vector();
    boolean populated; // styleProperties hash is ready
        
    public String getSelector() { return selector; }        
        
    public String [] getStatements()
    {
        if (statements == null ||
            (statements != null && 
             statementVector.size() > statements.length))
        {
            statements = new String[statementVector.size()];
            statementVector.copyInto(statements);
        }        
    
        return statements;
    }
    
    public boolean isPositional()
    {
        // iterate through the property keys
        Enumeration props = styleProperties.keys();
        while (props.hasMoreElements())
        {
            String prop = (String) props.nextElement();
            if (prop.equals(CssSyntax.PROP_BACKGROUND_COLOR) ||
                prop.equals(CssSyntax.PROP_LEFT))
            return true;
        }

        return false;
    }
    
    public Style(String selector)
    {
        this.selector = selector;   
    }        
    
    // statements as an attribute in the .xul document
    // come as a single string separated by a ';'
    public Style(String selector, String statementsStr)
    {
        this.selector = selector;
        
        // parse the statements
        statements = StringUtil.tokenize(statementsStr, ";");
    
        if (debug) System.out.println("# of statements: " + statements.length);
    
        // parse each statement, add to Hashtable
        for (int i=0; i < statements.length; i++)
        {
            String [] parts = StringUtil.tokenize(statements[i], ":"); 
            if (parts != null && parts.length == 2)
            {
                if (debug) System.out.println("Adding style prop: " + parts[0] + "," + parts[1]);
                parts[0] = parts[0].trim();
                parts[1] = parts[1].trim();
                styleProperties.put(parts[0], parts[1]);
            }
        }
        populated = true;
    }
    
    public Style(String selector, String [] statements)
    {
        
    }

    public void addStatement(String statement)
    {
        statementVector.addElement(statement);        
        
        // add to Style properties hash
        String [] parts = StringUtil.tokenize(statement, ":"); 
        if (parts != null && parts.length == 2)
        {
            if (debug) System.out.println("Adding style prop: " + parts[0] + "," + parts[1]);
            parts[0] = parts[0].trim();
            parts[1] = parts[1].trim();
            styleProperties.put(parts[0], parts[1]);
        }
    }

    // apply this style to a Component
    public void apply(Component c) throws XulFormatException
    {
        // get the component's "Rectangle"
        Rectangle r = new Rectangle(c.getX(), c.getY(), c.getWidth(), c.getHeight());
        
        // populate
        if (!populated)
            getStatements();
        
        // iterate through the property keys
        Enumeration props = styleProperties.keys();
        while (props.hasMoreElements())
        {
            String prop = (String) props.nextElement();
            String value = (String) styleProperties.get(prop);
            if (debug) System.out.println("prop<" + prop + ">, value<" + value + ">");
            if (prop.equals(CssSyntax.PROP_BACKGROUND_COLOR))
            {
                Color color = null;
                if (value.equals(CssSyntax.PROP_BACKGROUND_COLOR_LIGHTBLUE))
                    color = CssColors.COLOR_LIGHT_BLUE;
                else if (value.equals(CssSyntax.PROP_BACKGROUND_COLOR_LIGHTGRAY))
                    color = CssColors.COLOR_LIGHT_GRAY;
		else if (value.equals(CssSyntax.PROP_BACKGROUND_COLOR_BLUE))
                    color = CssColors.COLOR_BLUE;               
		else if (value.equals(CssSyntax.PROP_BACKGROUND_COLOR_RED))
                    color = CssColors.COLOR_RED;
                else if (value.equals(CssSyntax.PROP_BACKGROUND_COLOR_WHITE))
                    color = CssColors.COLOR_WHITE;
		else if (value.equals(CssSyntax.PROP_BACKGROUND_COLOR_GREEN))
		    color = CssColors.COLOR_GREEN;

                if (color != null)
                {
                    if (debug) System.out.println("Applying background color: " + value);
                    c.setBackground(color);
                }
            }
            else if (prop.equals(CssSyntax.PROP_LIST_STYLE_IMAGE))
            {
                // get the image
                if (value.indexOf("url") >= 0)
                {
                    // check if protocol or local image?
                    int openParenIdx = value.indexOf('(');
                    int closeParenIdx = value.indexOf(')');
                    if (openParenIdx >= 0 && closeParenIdx >= 0)
                    {
                        String surl = value.substring(openParenIdx + 1, closeParenIdx);
                        if (debug) System.out.println("image @ " + surl);

                        if (c instanceof XulImage)
                        {
                            XulImage ximg = (XulImage)c;
                            ximg.setImageSource(surl);
                            
                            /*
                              If there is no layout(in a JLayeredPane <stack>
                              for example) then we will need to set bounds. By this
                              time, we have already called a setBounds() on the object,
                              so we should know exactly the location of the position.
                              We must now do another setBounds() since the width & height
                              has changed. 
                              
                              */
                             
                                                 
                            JComponent jcomp = (JComponent)ximg; 
                            while (jcomp != null)
                            {
                            	Container parent = jcomp.getParent();
                            	if (parent != null)
                            	{
                            		Point loc = jcomp.getLocation();
                            		Dimension dim = jcomp.getPreferredSize();
                            		jcomp.setBounds(loc.x, loc.y, dim.width, dim.height);
                            				
                            		Container myparent = jcomp.getParent();
                            		if (myparent instanceof JComponent)
                            			jcomp = (JComponent)myparent;
                            		else
                            			jcomp = null;
                            	}
                            	else
                            	{
                            			jcomp = null;
                            	}
                            	
                            }	
                            
                        }
                        else
                            System.out.println("Unknown component: " + c.getClass().getName());                    
                    }
                    else
                        System.out.println("Error in value url: " + value);
                }
                else
                    System.out.println("Unknown Value: " + value);
            }
            else if (prop.equals(CssSyntax.PROP_LEFT))
            {
                /* an offset value for this component compared to
                   its container */
                // value is either length or a %
                if (value.indexOf('%') >= 0)
                {
                    System.out.println("TBD: handle percentages");
                    
                }
                else
                {
                    // unit id? (px, deg, etc.)                    
                    String digits = StringUtil.trimLetters(value);
                    
                    // length in pixels
                    if (value.indexOf("px") >= 0)
                    {
                        int left = Integer.parseInt(digits);
                        r.x += left;
                        if (debug) System.out.println("Setting the left Bound");
                        c.setBounds(r);
                    }
                    else
                        System.out.println("TBD: handle other unit types.");
                }
            }
            else if (prop.equals(CssSyntax.PROP_TOP))
            {
                /* an offset value for this component compared to
                   its container */
                // value is either length or a %
                if (value.indexOf('%') >= 0)
                {
                    System.out.println("TBD: handle percentages");
                    
                }
                else
                {
                    // unit id? (px, deg, etc.)                    
                    String digits = StringUtil.trimLetters(value);
                    
                    // length in pixels
                    if (value.indexOf("px") >= 0)
                    {
                        int top = Integer.parseInt(digits);
                        r.y += top;
                        if (debug) System.out.println("Setting the top Bound");
                        c.setBounds(r);                        
                    }
                    else
                        System.out.println("TBD: handle other unit types.");
                
                }                
            }
            else
            {
                // TBD
                System.out.println("Unhandled CSS Property: " + prop);    
            }
            
            /*
            else if (prop.equals())
            {
            
            }
            */
        }
    }
   
                         
    public String toString()
    {
        if (!populated)
            getStatements();
        StringWriter sw = new StringWriter();
        PrintWriter pw = new PrintWriter(sw);
        
        pw.println("Style{selector:" + selector + ",");
        pw.println("\tstatements:(");
        if (statements != null)
        {
            for (int i=0; i < statements.length; i++)
                pw.println("\t\t" + statements[i]);
        }
        pw.println("\t)");
        pw.println("}");
        return sw.toString();
    }

    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}
