/* XulImage.java */
package org.jxul.framework;

import java.io.*;
import javax.swing.*;
import java.awt.*;
import java.net.*;

import org.w3c.dom.*;

import org.jxul.util.*;

/**
 * A XUL Image.
 */
public class XulImage extends JComponent
{
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }
    
    private Element imageElement;
    // attributes
    String style;
    String id;
    String _class;
    String src;
    String onclick;
    ImageIcon icon;
    Image img;
    Dimension iconSize;
    
    public String getXulClass() { return _class; }
    
    public XulImage(Element imageElement) throws XulFormatException
    {
        this.imageElement = imageElement;

        Attr idAttr = imageElement.getAttributeNode(XulSyntax.IMAGE_ATTR_ID);

        Attr _classAttr = imageElement.getAttributeNode(XulSyntax.IMAGE_ATTR_CLASS);        
        if (_classAttr != null)
        {
            _class = _classAttr.getNodeValue();    
            if (debug) System.out.println("Image Element, class: " + _class);
        }
        
        Attr srcAttr = imageElement.getAttributeNode(XulSyntax.IMAGE_ATTR_SRC);
        if (srcAttr != null)
        {
            src = srcAttr.getNodeValue();
           
            if (src != null && src.length() > 0)
            {    
                if (src.indexOf("http:") >= 0 || src.indexOf("file:") >= 0 ||
                    src.indexOf("ftp:") >= 0)
                {
                    try
                    {
                    	
                        URL url = new URL(src);
                        icon = new ImageIcon(url);
                    } catch (MalformedURLException mfue)
                      {
                        throw new XulFormatException("Invalid url for Image src attribute");  
                      }
                }
                else
                {
                    // attempt to load this image
                    icon = new ImageIcon(src);                    
                }                
                
                iconSize = new Dimension(icon.getIconWidth(), icon.getIconHeight());
            }
        }
        
        Attr onclickAttr = imageElement.getAttributeNode(XulSyntax.IMAGE_ATTR_ONCLICK);
    
    }
    
    // src is a String url
    public void setImageSource(String src) throws XulFormatException
    {
        if (src.indexOf("http:") >= 0 || src.indexOf("file:") >= 0 ||
            src.indexOf("ftp:") >= 0)
        {
            try
            {
                URL url = new URL(src);
                icon = new ImageIcon(url);
            } catch (MalformedURLException mfue)
                {
                throw new XulFormatException("Invalid url for Image src attribute");  
                }
        }
        else
        {
            // attempt to load this image
            icon = new ImageIcon(src);                    
        }                
        iconSize = new Dimension(icon.getIconWidth(), icon.getIconHeight());
        if (debug) System.out.println("iconSize: " + iconSize);
        // invalidate this component
        invalidate();
    }
    
    public Dimension getMinimumSize()
    {
        if (icon != null)
        {
            return iconSize;   
        }
        else
            return new Dimension(10,10);
    }
    
    public Dimension getPreferredSize()
    {
        return getMinimumSize();    
    }
    
    public void paint(Graphics g)
    {
        super.paint(g);
        
        if (icon != null)
            icon.paintIcon(this, g, 0, 0);
    }
    
    /** for unit testing. */
    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}
