/* XulMenu.java */
package org.jxul.framework;

import java.io.*;
import java.util.*;
import javax.swing.*;
import java.awt.event.*;

import org.w3c.dom.*;

import org.jxul.util.*;

/**
 * A XUL Menu.
 */
public class XulMenu extends JMenu
{
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }
    
    private Element menuElement;
    // attributes
    String style;
    String label;
    String flex;
    String key;
    String disabled;
    String id;
    String _class;
    String acceltext;
    String accesskey;
    String crop;
    String orient;
    String autostretch;
    String oncommand;
    Hashtable peerMap;
    ActionListener listener;
    
    Hashtable buttonGroupHash;

    public XulMenu(Element menuElement, Hashtable peerMap) throws XulFormatException
    {
        this(menuElement, peerMap, null);    
    }
    
    public XulMenu(Element menuElement, Hashtable peerMap, ActionListener al) throws XulFormatException
    {
        this.listener = al;
        this.menuElement = menuElement;
        this.peerMap = peerMap;
        
        // TBD: complete the processing of all the attributes
        
        Attr labelAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_LABEL);
        if (labelAttr != null)
        {
            label = labelAttr.getNodeValue();
            if (label != null && !StringUtil.isBlank(label))
                this.setText(label);
        }
        
        Attr flexAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_FLEX);
        if (flexAttr != null)
            flex = flexAttr.getNodeValue();
            
        Attr keyAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_KEY);
        if (keyAttr != null)
            key = keyAttr.getNodeValue();
            
        Attr disabledAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_DISABLED);
        Attr idAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_ID);
        Attr _classAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_CLASS);
        Attr acceltextAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_ACCELTEXT);
        Attr accesskeyAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_ACCESSKEY);
        Attr cropAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_CROP);
        Attr orientAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_ORIENT);
        Attr autostretchAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_AUTOSTRETCH);
        Attr oncommandAttr = menuElement.getAttributeNode(XulSyntax.MENU_ATTR_ONCOMMAND);
        
        // process the children -- either menupopup or menuseparator
        processChildren();               
    }
    
    public void processChildren() throws XulFormatException
    {
        // should have menu children
        if (menuElement.hasChildNodes())
        {
            // children should be a set of Menu elements
            NodeList children = menuElement.getChildNodes();
            
            // iterate through each child, if a menu - create it
            int childCount = children.getLength();
            for (int i=0; i < childCount; i++)
            {
                // get the child node
                Node child = children.item(i);

                if (debug)
                   System.out.println("Child[" + i + "]" +
                   child.getNodeName() + "-" + child.getNodeValue());
 
                if (child.getNodeName().equals(XulSyntax.ELEMENT_MENUPOPUP))
                {
                    if (child.hasChildNodes())
                    {
                        // menupopup has menuitem children
                        // children should be a set of Menu item elements
                        NodeList miChildren = child.getChildNodes();
                        
                        // iterate through each child, if a menu item- create it
                        int miChildCount = miChildren.getLength();
                        for (int j=0; j < miChildCount; j++)
                        {
                            // get the child node
                            Node miChild = miChildren.item(j);
                            
                            if (miChild.getNodeName().equals(XulSyntax.ELEMENT_MENUITEM))
                            {
                                // create the menu item
                                JMenuItem menuItem = new XulMenuItem((Element) miChild);
                                
                                // check if a group item
                                if (((XulMenuItem)menuItem).isGroupItem())
                                {                                      
                                    // get the type
                                    String type = ((XulMenuItem)menuItem).getType();
                                    if (debug) System.out.println("Menu Item Type : " + type);
                                    if (type.equals(XulSyntax.MENUITEM_ATTR_TYPE_RADIO))
                                    {
                                        if (buttonGroupHash == null)
                                            buttonGroupHash = new Hashtable();
                                            
                                        // get the group name
                                        String name = ((XulMenuItem)menuItem).getName();
                                        if (name == null)
                                        {
                                            throw new XulFormatException("Name for group menu item should not be null!");    
                                        }
                                        
                                        // is there a button group for this name?
                                        ButtonGroup group = (ButtonGroup) buttonGroupHash.get(name);
                                        
                                        if (group == null)
                                        {
                                            group = new ButtonGroup();
                                            // associate with this name
                                            buttonGroupHash.put(name, group);
                                        }
                                    
                                        menuItem = new XulRadioMenuItem((Element) miChild);
                                        // add to the group
                                        group.add(menuItem);
                                    }
                                    else if (type.equals(XulSyntax.MENUITEM_ATTR_TYPE_CHECKBOX))
                                    {
                                        if (debug) System.out.println("Adding a checkbox");
                                        menuItem = new XulCheckBoxMenuItem((Element) miChild);                                        
                                    }
                                }
                                
                                // TBD: attach available event handler
                                if (listener != null)
                                    menuItem.addActionListener(listener);

                                // add it to the menu
                                this.add(menuItem);                                
                                
                                // add to peerMap
                                peerMap.put(miChild, menuItem);                                
                            } 
                            else if (miChild.getNodeName().equals(XulSyntax.ELEMENT_MENUSEPARATOR))
                            {
                                // add a separator 
                                this.add(new JSeparator());
                            }
                            if (miChild.getNodeName().equals(XulSyntax.ELEMENT_MENU))
                            {
                                // Nested Menus
                                XulMenu nestedMenu = new XulMenu((Element) miChild, peerMap, listener);
                                this.add(nestedMenu);
                            }
                        } // end of for (all menu item children)                    
                    } // end of if menupopup has children
                }                
            } // end of for (all children)
        } // end of if (children exist)       
    }
    
    /** for unit testing. */
    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}
