/* XulTabs.java */
package org.jxul.framework;

import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;

import org.w3c.dom.*;

import org.jxul.util.*;

/**
 * A XUL Tab Box. 
 */
public class XulTabs extends JTabbedPane
{
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }
    
    private Element tabsElement;
    // attributes
    String align;
    String _class;
    String flex;
    String id;
    String orient;
    String autostretch;
    String oncommand;
    Hashtable peerMap;
    public XulTabs(Element tabsElement, Hashtable peerMap) throws XulFormatException
    {
        this.tabsElement = tabsElement; 
	this.peerMap = peerMap;

        Attr alignAttr = tabsElement.getAttributeNode(XulSyntax.TABS_ATTR_ALIGN);
        if (alignAttr != null)
        {
            align = alignAttr.getNodeValue();
            if (align.equals(XulSyntax.TABS_ATTR_ALIGN_HORIZONTAL))
            {
                this.setTabPlacement(SwingConstants.TOP);    
            }
            else if (align.equals(XulSyntax.TABS_ATTR_ALIGN_VERTICAL))
            {
                this.setTabPlacement(SwingConstants.LEFT);    
            }
        }
        
        Attr _classAttr = tabsElement.getAttributeNode(XulSyntax.TABS_ATTR_CLASS);
        Attr flexAttr = tabsElement.getAttributeNode(XulSyntax.TABS_ATTR_FLEX);
        Attr idAttr = tabsElement.getAttributeNode(XulSyntax.TABS_ATTR_ID);
        Attr orientAttr = tabsElement.getAttributeNode(XulSyntax.TABS_ATTR_ORIENT);
        Attr autostretchAttr = tabsElement.getAttributeNode(XulSyntax.TABS_ATTR_AUTOSTRETCH);
        Attr oncommandAttr = tabsElement.getAttributeNode(XulSyntax.TABS_ATTR_ONCOMMAND);
        
        processChildren();
    } // end of XulTabs Constructor
        
    // tab control has different children than
    // the box
    public void processChildren() throws XulFormatException
    {
        // should have widget children
        if (tabsElement.hasChildNodes())
        {
            NodeList children = tabsElement.getChildNodes();
        
	    /*
	     * I probably want to do this differently. The tabs 
	     * corresponds directly to the next tabpanel sibling 
             * make sure that the next sibling is always a tabpanel  	
             */
	    Node sib = tabsElement.getNextSibling();  //tabpanels

	    Node sibkid = null; 
	    if (sib != null)
	    {
		sibkid = sib.getFirstChild();
		System.out.println("Next sibling is " + sib.getNodeName());
	    }
            // iterate through each child of tabs. Create all
            int childCount = children.getLength();
	    
            for (int i=0; i < childCount; i++)
            {
                // get the child node
                Node child = children.item(i);
               
                if (debug)
                    System.out.println("In <tabs>... Child[" + i + "]" +
                    child.getNodeName() + "-" + child.getNodeValue());
 
                // switch on the type of the child
               
                if (child.getNodeName().equals(XulSyntax.ELEMENT_TAB))
                {
                    XulTab tab = new XulTab((Element) child);
                    //this.add(tab.getValue(), tab);
		    peerMap.put(child, tab); 

		    //Okay, go to the corresponding element in the box
		    while (sibkid != null && sibkid.getNodeType() != Node.ELEMENT_NODE)
		    	sibkid = sibkid.getNextSibling();
		    if (sibkid != null)
		    {
			//okay - should be <tabpanel> widget at this point..
			if (sibkid.getNodeName().equals(XulSyntax.ELEMENT_TABPANEL) ||
			    sibkid.getNodeName().equals(XulSyntax.ELEMENT_BOX))
			{
				XulBox xb = new XulBox((Element)sibkid, peerMap);
		 		this.add(tab.getValue(), xb);
				System.out.println("just added tab " + tab.getValue());
				peerMap.put(sibkid, xb);
			}
			
		    }
		    sibkid = sibkid.getNextSibling();
 
		    //sets the selected component...
		    //if (tab.isSelected())
	            //		setSelectedComponent(tab);
                }              
            } // end of for (all children)
        } // end of if (children exist)                       
    }
    /** for unit testing. */
    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}
