/* XulText.java */
package org.jxul.framework;

import java.io.*;
import javax.swing.*;
import javax.swing.border.*;
import org.w3c.dom.*;
import org.jxul.util.*;

/**
 * A XUL Title tag is a TitledBorder
 */
public class XulTitle extends TitledBorder
{
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }
    
    private Element titleElement;
    // attributes
    String style;
    String value;
    String _class;
    String id;

    public XulTitle(Element titleElement)
    {
	    super("null");
        this.titleElement = titleElement;
        
        Attr _classAttr = titleElement.getAttributeNode(XulSyntax.TEXT_ATTR_CLASS);
        Attr idAttr = titleElement.getAttributeNode(XulSyntax.TEXT_ATTR_ID);

	    //ok, a <title> can contain text, or it contain HTML formatted text.
        //for now, let's skip the HTML formatting & just get the text.
        processChildren(titleElement); 
    }
    private void processChildren(Element node)
    {
	//go through them all & finally get text.
	Node childnode = node.getFirstChild();
	if (childnode != null)
	{
		switch (childnode.getNodeType())
		{
			case Node.ELEMENT_NODE:
			  if (childnode.getNodeName().equals(XulSyntax.ELEMENT_TEXT))
			  {	                              
			      String val = childnode.getNodeValue(); 
                                                                              
                  if (val != null) 
                       setTitle(XmlUtil.normalizeSpaces(val));                                                                       
                  else        
                  {                    	
                        Element textEl = (Element)childnode;
                        Attr titleValueAtt = textEl.getAttributeNode(XulSyntax.TEXT_ATTR_VALUE); 
                        if (titleValueAtt != null)                     
                            setTitle(XmlUtil.normalizeSpaces(titleValueAtt.getNodeValue()));
                  }
			  }
			  else if (childnode.getNodeName().equals(XulSyntax.ELEMENT_LABEL))
			  {
			  	/* Let's not actually add a XulLabel because we don't want 
			  	   to have a JLabel here. We just want the value of it..
			  	 */
			
			  	 XulLabel xl = new XulLabel((Element)childnode);
			  	 setTitle(xl.getText());
			  }
			  else
			  {
			     //assume HTML formatting.. ? 	
			     processChildren((Element)childnode);
			  }
			break;
			case Node.TEXT_NODE:	
			case Node.CDATA_SECTION_NODE:
				String val = childnode.getNodeValue();
				if (val != null)
					setTitle(XmlUtil.normalizeSpaces(val));	
			break;
		}
	}	
    } 
    /** for unit testing. */
    public static void main(String args[])
    {
        try
        {
            
        } 
        catch (Throwable t)  
        {
            t.printStackTrace();
        }
    }
}
