/* XulFrame.java */
package org.jxul.framework;

import java.io.*;
import java.util.*;
import javax.swing.*;
import java.awt.event.*;

import org.w3c.dom.*;

import org.jxul.util.*;
import org.jxul.css.*;


/**
 * A XUL ToolBar
 */
public class XulToolBar extends JToolBar
{
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }    

    private Element toolbarElement;

    // window attributes
    String style;
    String _class;
    String id;
    String chromeclass;
    String persist;
    String dragdroparea;
    String ondraggesture;
    String ondragdrop;
    String ondragover;
    String ondragexit;
    String tooltip;
    String orient;
    String autostretch;
    ActionListener listener;
    
    Style cssStyle;
    
    Hashtable peerMap;

    public XulToolBar(Element toolbarElement, Hashtable peerMap) throws XulFormatException
    {
        this(toolbarElement, peerMap, null);    
    }
    
    public XulToolBar(Element toolbarElement, Hashtable peerMap, ActionListener al) throws XulFormatException
    {
        this.listener = al;
        this.toolbarElement = toolbarElement;
        this.peerMap = peerMap;
        
        Attr idAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_ID);
        if (idAttr != null)
            id = idAttr.getNodeValue();
            
        Attr _classAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_CLASS);
        if (_classAttr != null)
            _class = _classAttr.getNodeValue();
            
        Attr persistAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_PERSIST);
        if (persistAttr != null)
            persist = persistAttr.getNodeValue();
            
        Attr dragdropareaAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_DRAGDROPAREA);
        if (dragdropareaAttr != null)
            dragdroparea = dragdropareaAttr.getNodeValue();
            
        Attr ondraggestureAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_ONDRAGGESTURE);
        if (ondraggestureAttr != null)
            ondraggesture = ondraggestureAttr.getNodeValue();

        Attr ondragdropAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_ONDRAGDROP);
        if (ondragdropAttr != null)
            ondragdrop = ondragdropAttr.getNodeValue();
       
        Attr ondragexitAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_ONDRAGEXIT);
        if (ondragexitAttr != null)
            ondragexit = ondragexitAttr.getNodeValue();

        Attr tooltipAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_TOOLTIP);
        if (tooltipAttr != null)
        {
            tooltip = tooltipAttr.getNodeValue();
            setToolTipText(tooltip);
        }
        Attr orientAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_ORIENT);
        if (orientAttr != null)
        {
            orient = orientAttr.getNodeValue();

            // set a Box Layout (if this is vertical or horizontal)
            if (orient.equals(XulSyntax.TOOLBAR_ATTR_ORIENT_VERTICAL))
                this.setOrientation(JToolBar.VERTICAL);
            else
                this.setOrientation(JToolBar.HORIZONTAL);
        }


        Attr autostretchAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBAR_ATTR_AUTOSTRETCH);
        if (autostretchAttr != null)
            autostretch = autostretchAttr.getNodeValue();         

        Attr styleAttr = toolbarElement.getAttributeNode(XulSyntax.TOOLBOX_ATTR_STYLE);
        if (styleAttr != null)
        {
            // styling overriding the .css stylesheet
            style = styleAttr.getNodeValue();

            if (style != null && style.length() > 0)
            {
                // TBD:
                // create a CSS Style
                cssStyle = new Style(Style.NONAME,style);

                // apply it
                cssStyle.apply(this);
            }
        }

        processChildren();
    } // end of XulToolBar Constructor

    public void processChildren() throws XulFormatException
    {
        // should have widget children
        if (toolbarElement.hasChildNodes())
        {
            /* only children should be a toolbar */
            NodeList children = toolbarElement.getChildNodes();

            // iterate through each child,  & create them

            int childCount = children.getLength();
            for (int i=0; i < childCount; i++)
            {
                // get the child node
                Node child = children.item(i);
                if (debug)
                     System.out.println("Child[" + i + "]" +
                     child.getNodeName() + "-" + child.getNodeValue());

                // switch on the type of the child
                if (child.getNodeName().equals(XulSyntax.ELEMENT_BOX))
                {
                    XulBox box = new XulBox((Element)child, peerMap);
                    if (cssStyle != null)
                        cssStyle.apply(box);
                    this.add(box);
                }
                if (child.getNodeName().equals(XulSyntax.ELEMENT_BUTTON))
                {
		            XulButton button = new XulButton((Element)child);
		            if (cssStyle != null)
			            cssStyle.apply(button);
                    
                    if (listener != null)
                        button.addActionListener(listener);
                        
                    this.add(button);                 
                }

            } // end of for (all children)
        } // end of if (children exist)
    }

    /** For unit testing. */
    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}
