/* XulTree.java */
package org.jxul.framework;

import java.awt.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;

import org.w3c.dom.*;

import org.jxul.util.*;
import org.jxul.framework.treetable.*;

/**
 * A XUL Tree
 */
public class XulTree extends JPanel
{
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }

    private Element treeElement;
	
    //contains these guys
    private XulTreeChildren m_treeChildren = null;
    private XulTreeHead m_treeHead = null;

    // attributes
    String align;
    String _class;
    String flex;
    String id;
    String orient;
    String onselect;
    Hashtable peerMap;

    public XulTree(Element treeElement, Hashtable peerMap) throws XulFormatException
    {
        this.treeElement = treeElement; 
	this.peerMap = peerMap;

	setLayout(new BorderLayout());

	/* TBD: Process These! */	
        Attr alignAttr = treeElement.getAttributeNode(XulSyntax.ATTR_ALIGN);
        Attr _classAttr = treeElement.getAttributeNode(XulSyntax.ATTR_CLASS);
        Attr flexAttr = treeElement.getAttributeNode(XulSyntax.ATTR_FLEX);
        Attr idAttr = treeElement.getAttributeNode(XulSyntax.ATTR_ID);
        Attr orientAttr = treeElement.getAttributeNode(XulSyntax.ATTR_ORIENT);
	
	//need to figure this one out
        Attr onselectAttr = treeElement.getAttributeNode(XulSyntax.TREE_ATTR_ONSELECT);
        
        processChildren();
    } // end of XulTree Constructor
        
    public void processChildren() throws XulFormatException
    {
        // should have widget children
        if (treeElement.hasChildNodes())
        {
            NodeList children = treeElement.getChildNodes();
         
            int childCount = children.getLength();
            for (int i=0; i < childCount; i++)
            {
                // get the child node
                Node child = children.item(i);
                String childName = child.getNodeName(); 
                if (debug)
		{
                    System.out.println("Child[" + i + "]" +
                    childName + "-" + child.getNodeValue());
		} 
                // switch on the type of the child
               
		if (childName.equals(XulSyntax.ELEMENT_TREECOLGROUP))
		{
			if (debug)
				System.out.println("*TBD* - treecolgroup");
		}
		else
		//should be the first child, or second after treecolgroup 
                if (childName.equalsIgnoreCase(XulSyntax.ELEMENT_TREEHEAD))
                {
			XulTreeHead th = new XulTreeHead((Element)child, peerMap);

			//This is important. It gives you the column values 
			//of your tree.

			peerMap.put(child, th);
			m_treeHead = th;	
                }
		else
		if (childName.equalsIgnoreCase(XulSyntax.ELEMENT_TREECHILDREN))
		{
			XulTreeChildren tc = new XulTreeChildren((Element)child, peerMap);
			peerMap.put(child, tc); 
			m_treeChildren = tc;
		} 
		else
		{
			System.out.println("TBD - tree did not include " + childName);	
		}
            } // end of for (all children)

	   //here's the big one! 
	   if (m_treeHead != null && m_treeChildren != null)
  	   {
		JTreeTable jt = new JTreeTable(new XulTreeModel(m_treeHead, m_treeChildren));
		add(new JScrollPane(jt), BorderLayout.SOUTH);
	   }
	   else if (m_treeHead == null && m_treeChildren != null)
	   {
		//need to convert these values to a JTree.. 
		System.out.println("*TBD* - Need to handle JTree without <treehead>");
	   }
	   else
	   {
		System.out.println("XulTree Error - <xultree> has no head or children");
	   }

        } // end of if (children exist)                       
    }
    /** for unit testing. */
    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}
