/* XulTreeItem.java */
package org.jxul.framework;

import java.io.*;
import java.util.*;
import org.w3c.dom.*;
import org.jxul.util.*;

/**
 * A XUL TreeItem, which is a complicated beast
 *
 * -If its container attribute is "true", then it
 * can be a button that will open up
 * items. 
 * -If its open attribute is "true" then the 
 *  items are opened already
 *-And there's a "hidden attribute
 * 
 * -It can contain a <treechildren> element,
 * or it can contain a <treerow> element.
 *
 */
public class XulTreeItem
{
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }

  
    private Element treeitemElement;

    //for use by XulTreeModel
    private XulTreeChildren m_treeChildren = null;
    private String m_itemName = "";
    private Vector m_rows = new Vector();
	

    // attributes
    String _class;
    String id;
    boolean treeContainer = false;
    boolean treeOpen = false;
    boolean treeHidden = false;

    Hashtable peerMap;

    public XulTreeItem(Element treeitemElement, Hashtable peerMap) throws XulFormatException
    {
        this.treeitemElement = treeitemElement; 
	this.peerMap = peerMap;

	//TBD - all this stuff
        Attr _classAttr = treeitemElement.getAttributeNode(XulSyntax.ATTR_CLASS);
        Attr idAttr = treeitemElement.getAttributeNode(XulSyntax.ATTR_ID);
        Attr openAttr = treeitemElement.getAttributeNode(XulSyntax.TREEITEM_ATTR_OPEN);
        Attr containerAttr = treeitemElement.getAttributeNode(XulSyntax.TREEITEM_ATTR_CONTAINER);
        Attr hiddenAttr = treeitemElement.getAttributeNode(XulSyntax.TREEITEM_ATTR_HIDDEN);
      
	if (containerAttr != null)
	{
		if (containerAttr.getNodeValue().equalsIgnoreCase("true"))
			treeContainer = true;
	}
	if (openAttr != null)
	{
		if (openAttr.getNodeValue().equalsIgnoreCase("true"))
			treeOpen = true;
	}
	if (hiddenAttr != null)
	{
		if (hiddenAttr.getNodeValue().equalsIgnoreCase("true"))
			treeHidden = true;
	}
        processChildren();


    } // end of XulTreeItem Constructor
        
    public void processChildren() throws XulFormatException
    {
        // should have widget children
        if (treeitemElement.hasChildNodes())
        {
            NodeList children = treeitemElement.getChildNodes();
         
            int childCount = children.getLength();
	    
            for (int i=0; i < childCount; i++)
            {
                // get the child node
                Node child = children.item(i);
                String childName = child.getNodeName(); 
                if (debug)
                    System.out.println("Child[" + i + "]" +
                    childName + "-" + child.getNodeValue());
 
                // switch on the type of the child
               
		if (childName.equals(XulSyntax.ELEMENT_TREEROW))
		{
			XulTreeRow  tr = new XulTreeRow((Element)child, peerMap);
			peerMap.put(tr, child);
			
			//OKAY - If it is a container, then it has rows & children,
                        //and therefore, has a value & a tree underneath it.. 
			if (treeContainer)
			{
				//the treerow underneath it should have one treecell.
				m_itemName = tr.getText(); 
			}
			else
			{
				//we may have many rows
				m_rows.add(tr);
			}
			
		}
		else if (childName.equalsIgnoreCase("treechildren"))
		{
			//there should only be one of these
			XulTreeChildren tc = new XulTreeChildren((Element)child, peerMap);
			peerMap.put(tc,child);
			m_treeChildren = tc;
		}
		else
                {
			if (debug)
				System.out.println("*TBD - " + childName);
                }
            } // end of for (all children)
        } // end of if (children exist)                       
    }

    //important for XulTreeModel
    public String getItemName()
    {
	return (m_itemName);
    }
    public Vector getRows()
    {
	return (m_rows);
    }
    public XulTreeChildren getTreeChildren()
    {
	return (m_treeChildren);
    }
    public boolean isContainer()
    {
	return (treeContainer);
    }
    public boolean isHidden()
    {
	return (treeHidden);
    }
    public boolean isOpen()
    {
 	return (treeOpen);
    }
 
    /** for unit testing. */
    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}
