/* XulFrame.java */
package org.jxul.framework;

import java.io.*;
import javax.swing.*;

import org.w3c.dom.*;

import org.jxul.util.*;

/**
 * A XUL Window.
 */
public class XulWindow extends JFrame
{
    public static final boolean debug;
    
    static
    {
        // this variation works in both applets and applications
        boolean temp = false;
        try
        {
            String sdebug = System.getProperty("debug");
            if (sdebug != null && sdebug.equalsIgnoreCase("true"))
                temp = true;
            else
                temp = false;
        } catch (Exception e)
          { }
        debug = temp;
    }    

    private Element windowElement;

    // window attributes
    String style;
    String title;
    String titlemodified;
    String titlemenuseparator;
    String id;
    String xmlns;
    String onload;
    String onunload;
    String windowtype;
    String align;
    protected int width = -1, height = -1;
    String persist;
    int x = -1, y = -1;
    String ondraggesture;
    
    public int getWidth() { return width; }
    public int getHeight() { return height; }
    public String getOnLoad() { return onload; }
    
    public XulWindow(Element windowElement)
    {
        this.windowElement = windowElement;
        
        // extract the attributes (if any)
        Attr titleAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_TITLE);
        if (titleAttr != null)
        {
            title = titleAttr.getNodeValue();
            if (title != null && !StringUtil.isBlank(title))
                this.setTitle(title);
        }
        
        Attr titlemodifiedAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_TITLEMODIFIED);
        if (titlemodifiedAttr != null)
            titlemodified = titlemodifiedAttr.getNodeValue();
        
        Attr titlemenuseparatorAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_TITLEMENUSEPARATOR);
        if (titlemenuseparatorAttr != null)
            titlemenuseparator = titlemenuseparatorAttr.getNodeValue();
            
        Attr idAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_ID);
        if (idAttr != null)
            id = idAttr.getNodeValue();
            
        Attr xmlnsAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_XMLNS);
        if (xmlnsAttr != null)
            xmlns = xmlnsAttr.getNodeValue();
            
        Attr onloadAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_ONLOAD);
        if (onloadAttr != null)
            onload = onloadAttr.getNodeValue();
            
        Attr onunloadAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_ONUNLOAD);
        if (onunloadAttr != null)
            onunload = onunloadAttr.getNodeValue();
            
        Attr windowtypeAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_WINDOWTYPE);
        if (windowtypeAttr != null)
        {        
            windowtype = windowtypeAttr.getNodeValue();

            // values for windowType????  Not specified in Xul Programmers Reference?
        
        }
        
        // alignment of the children
        Attr alignAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_ALIGN);
        if (alignAttr != null)
        {
            align = alignAttr.getNodeValue();
            
            // legal values for align?  Looks like "vertical" and "horizontal" in the examples
            // but that does not jive with the XUL Programmers Reference
            
            // set a Box Layout (if this is vertical or horizontal)
            if (align.equals(XulSyntax.WINDOW_ATTR_ALIGN_VERTICAL))
                this.getContentPane().setLayout(new BoxLayout(getContentPane(),BoxLayout.Y_AXIS));
            else
                this.getContentPane().setLayout(new BoxLayout(getContentPane(),BoxLayout.X_AXIS));                
        }
        
        if (getLayout() == null)
            this.getContentPane().setLayout(new BoxLayout(getContentPane(),BoxLayout.Y_AXIS));
                    
        Attr widthAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_WIDTH);
        if (widthAttr != null)
        {
            String widthStr = widthAttr.getNodeValue();
            width = Integer.parseInt(widthStr);
        }
        
        Attr heightAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_HEIGHT);
        if (heightAttr != null)
        {
            String heightStr = heightAttr.getNodeValue();
            height = Integer.parseInt(heightStr);
        }

        if (width > 0 && height > 0)
            this.setSize(width, height);
        
        Attr persistAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_PERSIST);
        if (persistAttr != null)
            persist = persistAttr.getNodeValue();
            
        Attr xAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_X);
        if (xAttr != null)
        {
            String xStr = xAttr.getNodeValue();
            x = Integer.parseInt(xStr);
        }
        
        Attr yAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_Y);
        if (yAttr != null)
        {
            String yStr = yAttr.getNodeValue();
            y = Integer.parseInt(yStr);
        }
        
        if (x > 0 && y > 0)
            this.setLocation(x,y);
        
        Attr ondraggestureAttr = windowElement.getAttributeNode(XulSyntax.WINDOW_ATTR_ONDRAGGESTURE);
        if (ondraggestureAttr != null)
            ondraggesture = ondraggestureAttr.getNodeValue();
    }
    
    // used to open OTHER xul windows
    public void open(String urlStr, String windowName, String windowFeatures)
    {
       
    }
    
    // used to open OTHER xul windows
    public void openDialog(String urlStr, String windowName, String windowFeatures)
    {
        
    }
    
    public void sizeToContent()
    {
        pack();   
    }

    /** For unit testing. */
    public static void main(String args[])
    {
        try
        {
            
        } catch (Throwable t)
          {
            t.printStackTrace();
          }
    }
}